EffectTracker = class();

function EffectTracker:Constructor()
	self:UpdateParty();
end

function EffectTracker:TrackEffects()
	if party ~= nil then
		local playerCount = party:GetMemberCount();
		Turbine.Shell.WriteLine("Current player count in raid/fellowship: "..playerCount);
		if self.effectList == nil then
			self.effectList = {};
		end
		for i = 1, playerCount do
			self:HandleEffects(party:GetMember(i));
		end
	end
end

function EffectTracker:HandleEffects(player)
	self.effectList[player:GetName()] = player:GetEffects();
	if self.effectAddedHandler == nil then
		self.effectAddedHandler = {};
	end
	self.effectAddedHandler[player:GetName()] = function(sender, args)
		for k, v in pairs(pluginData) do
			if string.find(sender:Get(args.Index):GetName(), k, 1, true) then
				if Turbine.Engine:GetGameTime() - sender:Get(args.Index):GetStartTime() < 1 then
					Turbine.Shell.WriteLine(player:GetName()..": "..v);
				end
			end
		end
	end
	AddCallback(player:GetEffects(), "EffectAdded", self.effectAddedHandler[player:GetName()]);
end

function EffectTracker:PartyChatEvent(msg)
	if msg:find("You have joined a Fellowship.", 1, true) then
		return true;
	elseif msg:find("You have joined a Raid.", 1, true) then
		return true;
	elseif msg:find("Your Raid has been disbanded.", 1, true) then
		return true;
	elseif msg:find("Your Fellowship has been disbanded.", 1, true) then
		return true;
	elseif msg:find("You leave your Fellowship.", 1, true) then
		return true;
	elseif msg:find("You leave your Raid.", 1, true) then
		return true;
	elseif msg:find("has left your Raid.", 1, true) then
		return true;
	elseif msg:find("has left your Fellowship.", 1, true) then
		return true;
	elseif msg:find("You dismiss .- from the fellowship.", 1, false) then
		return true;
	elseif msg:find("You dismiss .- from the Raid.", 1, false) then
		return true;
	elseif msg:find("You have been dismissed from your", 1, true) then
		return true;
	elseif msg:find("has been dismissed from your", 1, true) then
		return true;
	elseif msg:find("has joined your Fellowship.", 1, true) then
		return true;
	elseif msg:find("has joined your Raid.", 1, true) then
		return true;
	end
	return false;
end

function EffectTracker:ReloadPlugin()
	Turbine.PluginManager.LoadPlugin("PDTReloader");
end

function EffectTracker:UpdateParty()
	self.partyChangedHandler = function(sender, args)
		if args.ChatType == Turbine.ChatType.Standard then
			if self:PartyChatEvent(args.Message) then
				self:ReloadPlugin();
			end
		end
	end
	AddCallback(Turbine.Chat, "Received", self.partyChangedHandler);
	if party ~= nil then
		self:TrackEffects();
	end
end

function EffectTracker:RemoveEffectCallbacks()
	if self.effectList ~= nil then
		for k, v in pairs(self.effectList) do
			if v == nil then
				Turbine.Shell.WriteLine("v is nil");
			end
			RemoveCallback(v, "EffectAdded", self.effectAddedHandler[k]);
			self.effectAddedHandler[k] = nil;
			self.effectList[k] = nil;
		end
	end
end

function EffectTracker:RemovePartyCallbacks()
	RemoveCallback(Turbine.Chat, "Received", self.partyChangedHandler);
	party = nil;
	self.effectAddedHandler = nil;
	self.effectList = nil;
end