import "SDRPlugins.PartyDebuffTracker";
import "Turbine.Gameplay";
import "Turbine.UI";
import "Turbine.UI.Lotro";

PDTUnloader = Turbine.UI.Control();
PDTUnloader:SetWantsUpdates( true );

PDTUnloader.Update = function( sender, args )
	PDTUnloader:SetWantsUpdates( false );
	Turbine.PluginManager.UnloadScriptState("PDTReloader");
end

-- safely add a callback without overwriting any existing ones
function AddCallback(object, event, callback)
    if object[event] == nil then
        object[event] = callback;
    else
        if type(object[event]) == "table" then
            table.insert(object[event], callback);
        else
            object[event] = {object[event], callback};
        end
    end
end

-- safely remove a callback without clobbering any extras
function RemoveCallback(object, event, callback)
    if object[event] == callback then
        object[event] = nil;
    else
        if type(object[event]) == "table" then
            local size = table.getn(object[event]);
            for i = 1, size do
                if object[event][i] == callback then
                    table.remove(object[event], i);
                    break;
                end
            end
        end
    end
end

PDTMain = class();

function PDTMain:Constructor()
	localPlayer = Turbine.Gameplay.LocalPlayer:GetInstance();
	party = localPlayer:GetParty();
	pluginData = Turbine.PluginData.Load(Turbine.DataScope.Character, 'PDT') or self:InitializePluginData();
	self.EffectTracker = EffectTracker();
	
	self.OptionControl = OptionControl();

	plugin.GetOptionsPanel = function()
		return self.OptionControl;
	end
end

function PDTMain:SavePlugin()
	Turbine.PluginData.Save(Turbine.DataScope.Character, 'PDT', pluginData);
end

function PDTMain:RemoveCallbacks()
	self.EffectTracker:RemoveEffectCallbacks();
	self.EffectTracker:RemovePartyCallbacks();
end

function PDTMain:InitializePluginData()
	local data = {};

	-- Add initial trackers here.

	-- ToO trackers
	data["Impending Fear"] = "Must use FEAR pot!";
	data["Impending Wound"] = "Must use WOUND pot!";
	data["Impending Disease"] = "Must use DISEASE pot!";
	data["Impending Poison"] = "Must use POISON pot!";
	data["Acid"] = "Needs overheals!";
	data["Impending Pull"] = "Is about to be punted!";
	data["Disease"] = "Needs to cure disease or everyone will be stunned!";

	return data;
end

main = PDTMain();

Turbine.Plugin.Load = function(self, sender, args)
	Turbine.Shell.WriteLine("Party Debuff Tracker v" .. self:GetVersion() .. " by " .. self:GetAuthor() .. " loaded!");
	Version = self:GetVersion();
end

Turbine.Plugin.Unload = function(self, sender, args)
	main:RemoveCallbacks();
	main:SavePlugin();
	self.EffectTracker = nil;
	--plugin.GetOptionsPanel = nil;
	self.OptionControl = nil;
	PDTUnloader.Update = nil;
	PDTUnloader = nil;
end

-- create a new command line command for OPL options
pdtCommand = Turbine.ShellCommand();

-- handle the chat commands
function pdtCommand:Execute( name, shellCommand )
	if  shellCommand == "show" then
		main.OptionControl:Show();
	else 
		pdtCommand:GetHelp();
	end
end

-- The Help text that outputs when /pdt is typed
help = "PDT has the following command:\n" ..
	"show - Brings up the PDT window to edit effect tracking.";

function pdtCommand:GetHelp()
	Turbine.Shell.WriteLine( help );
end

-- add the command to the shell
Turbine.Shell.AddCommand( "pdt", pdtCommand );