import "Turbine.UI";

OptionControl = class(Turbine.UI.Control);

function OptionControl:Constructor()
	Turbine.UI.Control.Constructor(self);

	-- create the background control
	self:SetBackColor( Turbine.UI.Color( 0.1, 0.1, 0.1 ) );
	self:SetSize( 400, 400 );

	-- create a label at the top to explain how to edit trackers
	self.topLabel = Turbine.UI.Label();
	self.topLabel:SetParent(self);
	self.topLabel:SetBackColor(Turbine.UI.Color( 0.6, 0.6, 0.6 ));
	self.topLabel:SetSize(380,20);
	self.topLabel:SetPosition( 10, 10);
	self.topLabel:SetText("Select a Tracker Below to Edit");
	self.topLabel:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter);

	-- create a listbox under the label that stores all available trackers
	self.listbox = Turbine.UI.ListBox();
      	self.listbox:SetParent( self );
      	self.listbox:SetBackColor( Turbine.UI.Color( 0.2, 0.2, 0.2 ) );
      	self.listbox:SetPosition( 10, 40 );
      	self.listbox:SetSize( 380, 350 );

	-- create a scrollbar for the listbox
	scrollBar = self.listbox:GetVerticalScrollBar();
	if(scrollBar == nil ) then
		scrollBar = Turbine.UI.Lotro.ScrollBar();
	end
	scrollBar:SetBackColor(Turbine.UI.Color(0.87,0.1,0.1,0.1));
	scrollBar:SetOrientation( Turbine.UI.Orientation.Vertical );	
	scrollBar:SetSize( 10, 350 );
	scrollBar:SetPosition( 370,0);
	scrollBar:SetZOrder(100);
	scrollBar:SetVisible( true );
	scrollBar:SetParent(self.listbox);

	self.listbox:SetVerticalScrollBar(scrollBar);

	-- the initial tracker, also used to create new trackers
	self.newTracker = Turbine.UI.Label();
	self.newTracker:SetBackColor(Turbine.UI.Color( 0.5, 0.5, 0.5 ));
	self.newTracker:SetSize(380,20);
	self.newTracker:SetText("New Tracker - Click to Create a New Tracker");
	self.newTracker:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter);

	self.listbox:AddItem( self.newTracker );
	self.listbox:SetSelectedIndex(1);

	-- add already made trackers
	for k, v in pairs(pluginData) do
		local listItem = Turbine.UI.Label();
        	listItem:SetSize( 380, 20 );
		listItem:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter);
		listItem:SetBackColor(Turbine.UI.Color( 0.4, 0.4, 0.4 ));
		listItem:SetText(k);
        	self.listbox:AddItem( listItem );
	end

	-- create a label for the effect name text field
	self.effectNameLabel = Turbine.UI.Label();
	self.effectNameLabel:SetParent(self);
	self.effectNameLabel:SetBackColor(Turbine.UI.Color( 0.6, 0.6, 0.6 ));
	self.effectNameLabel:SetSize(380,20);
	self.effectNameLabel:SetPosition( 400, 10);
	self.effectNameLabel:SetText("Enter the Name of the Effect Below");
	self.effectNameLabel:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter);

	-- Create text field for user to enter effect name (which is also the tracker name)
	self.effectName = Turbine.UI.Lotro.TextBox();
	self.effectName:SetParent(self);
	self.effectName:SetBackColor(Turbine.UI.Color( 1.0, 1.0, 1.0 ));
	self.effectName:SetSize(380,25);
	self.effectName:SetPosition( 400, 40);

	-- change in selection handler for list items
	selectionChangedHandler = function(sender, args)
		local itemCount = self.listbox:GetItemCount();
		-- set all background colors to non-selected color
		for i = 1, itemCount do
			self.listbox:GetItem(i):SetBackColor(Turbine.UI.Color( 0.4, 0.4, 0.4 ));
		end
		-- set newly selected item's background color to selected color
		self.listbox:GetSelectedItem():SetBackColor(Turbine.UI.Color( 0.5, 0.5, 0.5 ))

		-- set effectName and chatOutput text boxes
		if pluginData[self.listbox:GetSelectedItem():GetText()] ~= nil then
			self.effectName:SetText(self.listbox:GetSelectedItem():GetText());
			self.chatOutput:SetText(pluginData[self.listbox:GetSelectedItem():GetText()]);
		else -- used for when user selects new effect
			self.effectName:SetText("");
			self.chatOutput:SetText("");
		end
	end
	self.listbox.SelectedIndexChanged = selectionChangedHandler;

	-- create a label for the chat output text field
	self.chatoutputLabel = Turbine.UI.Label();
	self.chatoutputLabel:SetParent(self);
	self.chatoutputLabel:SetBackColor(Turbine.UI.Color( 0.6, 0.6, 0.6 ));
	self.chatoutputLabel:SetSize(380,40);
	self.chatoutputLabel:SetPosition( 400, 85);
	self.chatoutputLabel:SetText("Enter the chat response you want for this effect. Please note the chat will start with the player name.");
	self.chatoutputLabel:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter);

	-- Create text field for user to enter effect name (which is also the tracker name)
	self.chatOutput = Turbine.UI.Lotro.TextBox();
	self.chatOutput:SetParent(self);
	self.chatOutput:SetBackColor(Turbine.UI.Color( 1.0, 1.0, 1.0 ));
	self.chatOutput:SetSize(380,25);
	self.chatOutput:SetPosition( 400, 135);

	-- Create a Save button
	self.saveButton = Turbine.UI.Lotro.Button();
	self.saveButton:SetParent(self);
	self.saveButton:SetBackColor(Turbine.UI.Color( 0.2, 0.8, 0.5 ));
	self.saveButton:SetSize(380,40);
	self.saveButton:SetPosition( 400, 175);
	self.saveButton:SetText("Save Tracker");
	self.saveButton:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter);
	self.saveButton.MouseClick = function(sender, args)
		if self.effectName:GetText() ~= "" then --effectName must have text, otherwise it won't save properly
			if self.effectName:GetText() ~= self.listbox:GetSelectedItem():GetText() then -- if the effectName and the selected item have different text, update the effect
				pluginData[self.listbox:GetSelectedItem():GetText()] = nil; -- set the old one to nil to delete it
			end
			pluginData[self.effectName:GetText()] = self.chatOutput:GetText(); -- sets new effectTracker
			if self.listbox:GetSelectedIndex() == 1 then -- when creating a new effectTracker, update listbox and select newly created effectTracker
				local listItem = Turbine.UI.Label();
        			listItem:SetSize( 380, 20 );
				listItem:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter);
				listItem:SetBackColor(Turbine.UI.Color( 0.4, 0.4, 0.4 ));
				listItem:SetText(self.effectName:GetText());
        			self.listbox:AddItem( listItem );
				self.listbox:SetSelectedItem(listItem);
			else -- otherwise, update previous listbox item with the new effectTracker name
				self.listbox:GetSelectedItem():SetText(self.effectName:GetText());
			end
			main:SavePlugin();
		end
	end
	
	-- Create a delete button
	self.deleteButton = Turbine.UI.Lotro.Button();
	self.deleteButton:SetParent(self);
	self.deleteButton:SetBackColor(Turbine.UI.Color( 0.2, 0.8, 0.5 ));
	self.deleteButton:SetSize(380,40);
	self.deleteButton:SetPosition( 400, 225);
	self.deleteButton:SetText("Delete Tracker");
	self.deleteButton:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter);
	self.deleteButton.MouseClick = function(sender, args)
		if self.listbox:GetSelectedIndex() ~= 1 then  -- only delete effectTrackers if it isn't the "create new effectTracker" label
			pluginData[self.listbox:GetSelectedItem():GetText()] = nil;
			self.listbox:RemoveItem(self.listbox:GetSelectedItem());
			self.listbox:SetSelectedIndex(1);
			main:SavePlugin();
		end
	end
end

function OptionControl:Show()
	Turbine.PluginManager.ShowOptions(Plugins["PartyDebuffTracker"])
end